@@ -1,7 +1,7 @@
 package Perinci::CmdLine::POD;
 
-our $DATE = '2017-02-13'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $DATE = '2017-02-24'; # DATE
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -350,6 +350,7 @@ sub gen_pod_for_pericmd_script {
         $program_name = $args{script};
         $program_name =~ s!.+/!!;
     }
+    $program_name //= "program";
     my $summary = $args{summary} // $cli->{summary} //
         $metas{''}{summary} // '(no summary)';
 
@@ -406,8 +407,10 @@ sub gen_pod_for_pericmd_script {
 
         my @examples;
         for my $sc_name (sort keys %clidocdata) {
-            next unless length $sc_name;
-            if (defined $gen_sc) { next unless $sc_name eq $gen_sc }
+            if ($cli->{subcommands}) {
+                next unless length $sc_name;
+                if (defined $gen_sc) { next unless $sc_name eq $gen_sc }
+            }
             my $i = 1;
             for my $eg (@{ $clidocdata{$sc_name}{examples} }) {
                 # add pointer to subcommand, we need it later to show result
@@ -967,7 +970,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.009 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-13.
+This document describes version 0.010 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-24.
 
 =head1 SYNOPSIS
 
